@@ -1,8 +1,9 @@
 # file MASS/polr.q
 # copyright (C) 1994-2003 W. N. Venables and B. D. Ripley
 #
-polr <- function(formula, data = NULL, weights, start, ..., subset,
-                 na.action = na.fail, contrasts = NULL, Hess=FALSE)
+polr <- function(formula, data, weights, start, ..., subset,
+                 na.action, contrasts = NULL, Hess = FALSE,
+                 model = TRUE)
 {
     logit <- function(p) log(p/(1-p))
 
@@ -23,7 +24,6 @@ polr <- function(formula, data = NULL, weights, start, ..., subset,
         p2 <- dlogis(gamm[y] - eta)
         g1 <- if(pc > 0) t(x) %*% (wt*(p1-p2)/pr) else numeric(0)
         xx <- .polrY1*p1 - .polrY2*p2
-        d <- pmin(diff(beta[pc+1:q]), 0)
         g2 <- - t(xx) %*% (wt/pr)
         if(all(pr) > 0) c(g1, g2) else rep(NA, pc+q)
     }
@@ -36,12 +36,6 @@ polr <- function(formula, data = NULL, weights, start, ..., subset,
     m <- eval.parent(m)
     Terms <- attr(m, "terms")
     x <- model.matrix(Terms, m, contrasts)
-    xvars <- as.character(attr(Terms, "variables"))[-1]
-    if ((yvar <- attr(Terms, "response")) > 0) xvars <- xvars[-yvar]
-    xlev <- if (length(xvars) > 0) {
-        xlev <- lapply(m[xvars], levels)
-        xlev[!sapply(xlev, is.null)]
-    }
     xint <- match("(Intercept)", colnames(x), nomatch=0)
     n <- nrow(x)
     pc <- ncol(x)
@@ -50,11 +44,11 @@ polr <- function(formula, data = NULL, weights, start, ..., subset,
         x <- x[, -xint, drop=FALSE]
         pc <- pc - 1
     } else warning("an intercept is needed and assumed")
-    wt <- model.extract(m, weights)
+    wt <- model.weights(m)
     if(!length(wt)) wt <- rep(1, n)
-    offset <- model.extract(m, offset)
+    offset <- model.offset(m)
     if(length(offset) <= 1) offset <- rep(0, n)
-    y <- model.extract(m, response)
+    y <- model.response(m)
     if(!is.factor(y)) stop("response must be a factor")
     lev <- levels(y)
     if(length(lev) <= 2) stop("response must have 3 or more levels")
@@ -64,7 +58,7 @@ polr <- function(formula, data = NULL, weights, start, ..., subset,
     assign(".polrY1", col(Y) == y)
     assign(".polrY2", col(Y) == y-1)
     if(missing(start)) {
-        # try logistic regression on `middle' cut
+        # try logistic regression on 'middle' cut
         q1 <- length(lev) %/% 2
         y1 <- (y > q1)
         X <- cbind(Intercept = rep(1, n), x)
@@ -98,10 +92,10 @@ polr <- function(formula, data = NULL, weights, start, ..., subset,
         dimnames(H) <- list(dn, dn)
         fit$Hessian <- H
     }
-    attr(fit, "na.message") <- attr(m, "na.message")
-    if(!is.null(attr(m, "na.action"))) fit$na.action <- attr(m, "na.action")
+    if(model) fit$model <- m
+    fit$na.action <- attr(m, "na.action")
     fit$contrasts <- cons
-    fit$xlevels <- xlev
+    fit$xlevels <- .getXlevels(Terms, m)
     class(fit) <- "polr"
     fit
 }
@@ -197,6 +191,8 @@ predict.polr <- function(object, newdata, type=c("class","probs"), ...)
         Terms <- delete.response(object$terms)
         m <- model.frame(Terms, newdata, na.action = function(x) x,
                          xlev = object$xlevels)
+        if (!is.null(cl <- attr(Terms, "dataClasses")) &&
+            exists(".checkMFClasses", envir=NULL)) .checkMFClasses(cl, m)
         X <- model.matrix(Terms, m, contrasts = object$contrasts)
         xint <- match("(Intercept)", colnames(X), nomatch=0)
         if(xint > 0) X <- X[, -xint, drop=FALSE]
@@ -222,16 +218,22 @@ extractAIC.polr <- function(fit, scale = 0, k = 2, ...)
     c(edf, deviance(fit) + k * edf)
 }
 
-model.frame.polr <- function(formula, data, na.action, ...)
+model.frame.polr <- function(formula, ...)
 {
-    m <- formula$call
-    m$start <- m$Hess <- m$... <- NULL
-    m[[1]] <- as.name("model.frame")
-    data <- eval.parent(m)
-    if(!is.null(mw <- m$weights)) {
-        nm <- names(data)
-        nm[match("(weights)", nm)] <- as.character(mw)
-        names(data) <- nm
-    }
-    data
+    dots <- list(...)
+    nargs <- dots[match(c("data", "na.action", "subset"), names(dots), 0)]
+    if(any(nargs > 0) || is.null(formula$model)) {
+        m <- formula$call
+        m$start <- m$Hess <- m$... <- NULL
+        m[[1]] <- as.name("model.frame")
+        m[names(nargs)] <- nargs
+        if (is.null(env <- environment(formula$terms))) env <- parent.frame()
+        data <- eval(m, env)
+        if(!is.null(mw <- m$weights)) {
+            nm <- names(data)
+            nm[match("(weights)", nm)] <- as.character(mw)
+            names(data) <- nm
+        }
+        data
+    } else formula$model
 }
