@@ -21,7 +21,6 @@ c(3, 5, 6, 7, 8, 10, 11, 16, 20, 21, 22, 23, 24, 25, 29, 33, 39, 41, 44, 45,
 174, 175, 176, 177, 183, 184, 187, 188, 189, 194, 195, 196, 197, 198,
 199, 202, 204, 205, 206, 208, 209)
 
-data(cpus)
 cpus1 <- cpus
 attach(cpus)
 for(v in names(cpus)[2:7])
@@ -41,7 +40,6 @@ test.cpus <- function(fit)
 
 # 8.1 An introductory example
 
-data(wtloss)
 attach(wtloss)
 # alter margin 4; others are default
 oldpar <- par(mar = c(5.1, 4.1, 4.1, 4.1))
@@ -55,7 +53,6 @@ detach()
 
 # 8.2  Fitting non-linear regression models
 
-library(nls)
 wtloss.st <- c(b0 = 90, b1 = 95, th = 120)
 wtloss.fm <- nls(Weight ~ b0 + b1*2^(-Days/th),
    data = wtloss, start = wtloss.st, trace = T)
@@ -91,7 +88,6 @@ summary(wtloss.gr)
 deviance(wtloss.gr)
 vcov(wtloss.gr)
 
-data(muscle)
 A <- model.matrix(~ Strip - 1, data = muscle)
 rats.nls1 <- nls(log(Length) ~ cbind(A, rho^Conc),
    data = muscle, start = c(rho = 0.1), algorithm = "plinear")
@@ -142,7 +138,6 @@ for(w0 in w0s) {
 dimnames(out)[[1]] <- paste(w0s,"kg:")
 out
 
-data(stormer)
 fm0 <- lm(Wt*Time ~ Viscosity + Time - 1,  data = stormer)
 b0 <- coef(fm0)
 names(b0) <- c("b1", "b2")
@@ -209,8 +204,6 @@ par(opar)
 
 # 8.7  One-dimensional curve fitting
 
-library(modreg)
-data(GAGurine)
 attach(GAGurine)
 par(mfrow = c(3, 2))
 plot(Age, GAG, main = "Degree 6 polynomial")
@@ -222,6 +215,7 @@ GAG.lm2 <- lm(GAG ~ Age + I(Age^2) + I(Age^3) + I(Age^4) +
 xx <- seq(0, 17, len = 200)
 lines(xx, predict(GAG.lm2, data.frame(Age = xx)))
 
+library(splines)
 plot(Age, GAG, type = "n", main = "Splines")
 lines(Age, fitted(lm(GAG ~ ns(Age, df = 5))))
 lines(Age, fitted(lm(GAG ~ ns(Age, df = 10))), lty = 3)
@@ -258,7 +252,6 @@ detach()
 
 ## R has a different gam() in package mgcv
 library(mgcv)
-data(rock)
 rock.lm <- lm(log(perm) ~ area + peri + shape, data = rock)
 summary(rock.lm)
 (rock.gam <- gam(log(perm) ~ s(area) + s(peri) + s(shape), data=rock))
@@ -339,8 +332,6 @@ detach()
 
 # 8.9  Projection-pursuit regression
 
-library(modreg)
-data(rock)
 attach(rock)
 rock1 <- data.frame(area = area/10000, peri = peri/10000,
                     shape = shape, perm = perm)
@@ -381,7 +372,6 @@ cpus.ppr2 <- ppr(log10(perf) ~ ., data = cpus2[cpus.samp,],
 test.cpus(cpus.ppr2)
 res3 <- log10(cpus2[-cpus.samp, "perf"]) -
              predict(cpus.ppr, cpus2[-cpus.samp,])
-library(ctest)
 wilcox.test(res2^2, res3^2, paired = T, alternative = "greater")
 
 
